@@ -22,6 +22,7 @@ from selenium.webdriver import ActionChains
 from selenium.webdriver.chrome.options import Options
 import platform
 import pathlib
+import os
 
 from recurrent import Recurrent
 
@@ -99,7 +100,8 @@ class Handler:
     def shorteningService(self):
         url = self.url
         short_url, long_url = url, ''
-        shortening_services = str(pathlib.Path(__file__).parent.absolute()) + r'\data\shortening_services.txt'
+        path = str(pathlib.Path(__file__).parent.absolute())
+        shortening_services =  os.path.join(path, "data", "shortening_services.txt")
         test_read = open(shortening_services, 'r')
         
         havingIP = Handler.havingIPAddress(self)
@@ -188,7 +190,8 @@ class Handler:
             if(len(issued_by.split(" "))>1):
                 CA = issued_by.split(" ")[0] + " " + issued_by.split(" ")[1] 
             
-            ssl_list = str(pathlib.Path(__file__).parent.absolute()) + r'\data\ssl_list.txt'
+            path = str(pathlib.Path(__file__).parent.absolute())
+            ssl_list = os.path.join(path, "data", "ssl_list.txt")
             SSL_read = open(ssl_list,'r')
             
             if((issued_by.split()[0] or CA)in SSL_read.read()):
@@ -199,7 +202,8 @@ class Handler:
                 return 1
     
     def domainRegistration(self):
-        edu_domains = str(pathlib.Path(__file__).parent.absolute()) + r'\data\edu_domains.txt'
+        path = str(pathlib.Path(__file__).parent.absolute())
+        edu_domains = os.path.join(path, "data", "edu_domains.txt")
         test_read = open(edu_domains, 'r')
         parts = self.parts
         domain_name = parts.netloc
@@ -686,13 +690,16 @@ class Handler:
         
         OS = str(platform.system()).lower()
         if('windows' in OS):
-            chromedriver_windows = str(pathlib.Path(__file__).parent.absolute()) + r'\dependencies\windows\chromedriver.exe'
+            windows_path = str(pathlib.Path(__file__).parent.absolute())
+            chromedriver_windows = os.path.join(windows_path, "dependencies/windows", "chromedriver.exe")
             driver = webdriver.Chrome(executable_path=chromedriver_windows, options=chrome_options)
         elif('linux' in OS):
-            chromedriver_linux = str(pathlib.Path(__file__).parent.absolute()) + r'\dependencies\linux\chromedriver'
+            linux_path = str(pathlib.Path(__file__).parent.absolute())
+            chromedriver_linux = os.path.join(linux_path, "dependencies/linux", "chromedriver")
             driver = webdriver.Chrome(executable_path=chromedriver_linux, options=chrome_options)
         elif('darwin' in OS):
-            chromedriver_macOS = str(pathlib.Path(__file__).parent.absolute()) + r'\dependencies\macOS\chromedriver'
+            macOS_path = str(pathlib.Path(__file__).parent.absolute())
+            chromedriver_macOS = os.path.join(macOS_path, "dependencies/macOS", "chromedriver")
             driver = webdriver.Chrome(executable_path=chromedriver_macOS, options=chrome_options)
         else:
             driver = None
